@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: DwmAuthPeerAuthenticator.cc 11162 2020-09-08 06:46:41Z dwm $
+// @(#) $Id: DwmAuthPeerAuthenticator.cc 11215 2020-11-10 05:34:23Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2017, 2020
 //  All rights reserved.
@@ -66,7 +66,7 @@ extern "C" {
 #include "DwmAuthSymCrypto.hh"
 #include "DwmAuthUtils.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.6/src/DwmAuthPeerAuthenticator.cc 11162 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.7/src/DwmAuthPeerAuthenticator.cc 11215 $");
 
 using namespace std;
 using CryptoPP::PSS;
@@ -406,6 +406,10 @@ namespace Dwm {
         socklen_t           sockLen = sizeof(sockAddr);
         getpeername(fd, (struct sockaddr *)&sockAddr, &sockLen);
 
+        int origTcpNoDelay;
+        socklen_t  tcpNoDelayLen = sizeof(origTcpNoDelay);
+        getsockopt(fd, IPPROTO_TCP, TCP_NODELAY, (char *)&origTcpNoDelay,
+                   &tcpNoDelayLen);
         int tcpNoDelay = 1;
         setsockopt(fd, IPPROTO_TCP, TCP_NODELAY, (char *)&tcpNoDelay,
                    sizeof(tcpNoDelay));
@@ -449,6 +453,8 @@ namespace Dwm {
           Syslog(LOG_ERR, "ECDH exhange with %s failed",
                  inet_ntoa(sockAddr.sin_addr));
         }
+        setsockopt(fd, IPPROTO_TCP, TCP_NODELAY, (char *)&origTcpNoDelay,
+                   sizeof(origTcpNoDelay));
       }
       return rc;
     }
@@ -463,6 +469,10 @@ namespace Dwm {
       bool  rc = false;
       theirId.clear();
       agreedKey.clear();
+      boost::asio::ip::tcp::no_delay  origNoDelayOption;
+      sck.get_option(origNoDelayOption);
+      boost::asio::ip::tcp::no_delay  noDelayOption(true);
+      sck.set_option(noDelayOption);
       Auth::ECDHAgreement  agreement;
       if (ECExchange(sck, agreement)) {
         string  theirIdCrypted, theirSig;
@@ -501,6 +511,7 @@ namespace Dwm {
       else {
         Syslog(LOG_ERR, "ECDH exhange failed");
       }
+      sck.set_option(origNoDelayOption);
       return rc;
     }
 
